@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Regexp::Pattern;
 
-our $DATE = '2018-09-10'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2019-12-17'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -86,7 +86,10 @@ sub _process_module {
         for my $patname (@patnames) {
             my $patspec = $var->{$patname};
             push @pod, "=item * $patname\n\n";
-            push @pod, $patspec->{summary}, ".\n\n" if $patspec->{summary};
+            if (defined $patspec->{summary}) {
+                require String::PodQuote;
+                push @pod, String::PodQuote::pod_quote($patspec->{summary}), ".\n\n";
+            }
             push @pod, $self->_md2pod($patspec->{description})
                 if $patspec->{description};
 
@@ -98,7 +101,10 @@ sub _process_module {
                     for my $argname (sort keys %{ $patspec->{gen_args} }) { # XXX sort by position, then name
                         my $argspec = $patspec->{gen_args}{$argname};
                         push @pod, "=item * $argname\n\n";
-                        push @pod, $argspec->{summary}, ".\n\n" if $argspec->{summary};
+                        if (defined $argspec->{summary}) {
+                            require String::PodQuote;
+                            push @pod, String::PodQuote::pod_quote($argspec->{summary}), ".\n\n";
+                        }
                         push @pod, $self->_md2pod($argspec->{description})
                             if $argspec->{description};
                     }
@@ -118,7 +124,10 @@ sub _process_module {
                 last unless @eg;
                 push @pod, "Examples:\n\n";
                 for my $eg (@eg) {
-                    push @pod, " # $eg->{summary}\n" if defined $eg->{summary};
+                    if (defined $eg->{summary}) {
+                        require String::PodQuote;
+                        push @pod, String::PodQuote::pod_quote($eg->{summary}), ".\n\n";
+                    }
 
                     push @pod, " ", dmp($eg->{str}), " =~ re(", dmp("$rp_package\::$patname"), ($eg->{gen_args} ? ", ".dmp($eg->{gen_args}) : ""), "); ";
                     if (ref $eg->{matches} eq 'ARRAY') {
@@ -196,7 +205,7 @@ Pod::Weaver::Plugin::Regexp::Pattern - Plugin to use when building Regexp::Patte
 
 =head1 VERSION
 
-This document describes version 0.003 of Pod::Weaver::Plugin::Regexp::Pattern (from Perl distribution Pod-Weaver-Plugin-Regexp-Pattern), released on 2018-09-10.
+This document describes version 0.004 of Pod::Weaver::Plugin::Regexp::Pattern (from Perl distribution Pod-Weaver-Plugin-Regexp-Pattern), released on 2019-12-17.
 
 =head1 SYNOPSIS
 
@@ -251,7 +260,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
